/*-----------------------------------------------------------------------
venice_empirics.do

Stata do file to replicate the empirical results of the article
'International trade and institutional change: 
Medieval Venice's response to globalization',
by Diego Puga and Daniel Trefler,
Quarterly Journal of Economics.
-----------------------------------------------------------------------*/

* open log
set more off
quietly capture log close
log using venice_empirics, text replace
* define temp files
tempfile tmp
tempfile stdseats

/* 
prepare great council data
*/
* read great council data
use venice_greatcouncil, clear
* count total seats per session
tab gc_session_start
gen ones = 1
by gc_session_start, sort: egen seats_session = sum(ones)
* count non-standardized family names
codebook familyname, compact
* count standardised family names
codebook familyname_std, compact
* aggregate by std familyname and gc session
collapse (sum) ones, by(familyname_std gc_session_start seats_session)
rename ones seats_family_session

/* 
calculate seat measures for each std family name
*/
preserve
* calculate number of sessions contained in the data
by gc_session_start, sort: gen sessions_ = _n == 1 
egen sessions = total(sessions_)
drop sessions_
* count total seats per std family name
collapse (sum) seats_family_session (first) sessions, by(familyname_std)
rename seats_family_session seats_family
* count seats per year
gen seats_family_peryear = seats_family / sessions
* calculate seat rank
egen seats_family_rank = rank(-seats_family), track
* calculate percentile in seat distribution
gen seats_family_pctl = 100 * (1 - seats_family_rank / _N)
keep familyname_std seats_family seats_family_peryear seats_family_rank seats_family_pctl
sort familyname_std
* save in temp file for later use
save `stdseats', replace
restore

/* 
figure: cumulative shares for families 
ordered by seat shares in 1261, 1264-65
*/
* define the 2 periods
gen period = .
replace period = 1 if gc_session_start >= 1261 & gc_session_start <= 1265
replace period = 2 if gc_session_start >= 1293 & gc_session_start <= 1295
drop if missing(period)
* aggregate by std familyname and period
collapse (sum) seats_family = seats_family_session, by(familyname_std period)
* calculate seat shares for families
by period, sort: egen seats_period = sum(seats_family)
gen family_pct_ = 100*seats_family/seats_period
drop seats_period
* put 2 periods side by side
reshape wide family_pct_ seats_family, i(familyname_std) j(period)
replace family_pct_1 = 0 if missing(family_pct_1)
replace family_pct_2 = 0 if missing(family_pct_2)
* rank families by decreasing seat shares
egen family_rank_1 = rank(-family_pct_1), track
egen family_rank_2 = rank(-family_pct_2), track
* order for figure
gsort +family_rank_1 +family_rank_2 +familyname
gen family_order = _n
* calculate cumulative shares
gen family_pct_1_cum = sum(family_pct_1)
gen family_pct_2_cum = sum(family_pct_2)
* plot figure
twoway (line family_pct_1_cum family_order, lcolor(navy) /*
*/ xtitle("Families ordered by Great Council seat share in 1261, 1264-65") /*
*/ ytitle("Cumulative share of Great Council seats") /*
*/ xlabel(1 20(20)220) /*
*/ ylabel(0 "0%" 10 "10%" 20 "20%" 30 "30%" 40 "40%" 50 "50%" 60 "60%" 70 "70%" 80 "80%" 90 "90%" 100 "100%", angle(horizontal)) /*
*/ legend(off) lpattern(dash)) /*
*/ (line family_pct_2_cum family_order, lcolor(red))
* save as eps
*graph export "venice_fsrc_gcouncil.eps", as(eps) preview(off) replace

/* 
numbers for the text
*/
format family_pct_1 family_pct_2 family_pct_1_cum family_pct_2_cum %9.1f
* family with the most seats in 1st period
list familyname family_pct_1 family_pct_1_cum if family_rank_1 == 1
* family with the second most seats in 1st period
list familyname family_pct_1 family_pct_1_cum if family_rank_1 == 2
* number of families holding 30% of seats in 1st period
list family_order family_pct_1_cum if family_pct_1_cum >= 29 & family_pct_1_cum < 31
* number of families holding 50% of seats in 1st period
list family_order family_pct_1_cum if family_pct_1_cum >= 49 & family_pct_1_cum < 50.1
* number of families holding 75% of seats in 1st period
list family_order family_pct_1_cum if family_pct_1_cum > 74.5 & family_pct_1_cum < 75
* number of families holding 100% of seats in 1st period
count if family_pct_1 > 0
* % of seats held in 2nd period by families with seats in 1st period (displayed as max)
sum family_pct_2_cum if family_pct_1 > 0
* number of new families in 2nd period
count if family_pct_1 == 0 & family_pct_2 > 0
* families who initially had seats, but ended up with none
count if family_pct_1 > 0 & family_pct_2 == 0
* entrants with most seats
list familyname family_rank_2 family_pct_2 if family_pct_1 == 0 & family_rank_2 < 50
* exiters family with most seats
list familyname family_rank_1 family_pct_1 if family_pct_2 == 0 & family_rank_1 < 50
* count al families
count

/* 
centrality in marriage network
*/
* read marriage data
use venice_marriages, clear
count
* keep only noble couples
keep if !missing(wife_familyname_std)
rename wife_familyname_std wife
rename husband_familyname_std husband
count
* define periods
gen period = .
replace period = 1 if year >= 1400 & year < 1499
replace period = 2 if year >= 1500 & year < 1599
drop if missing(period)
count
count if period == 1
count if period == 2
* output individual marriages to draw network in gephi (https://gephi.org)
outsheet husband wife if period == 1 using marriages_1400s.csv, comma nonames replace
* compile complete list of familynames in marriage data
preserve
rename husband f
keep f
save `tmp', replace
restore
preserve
rename wife f
keep f
append using `tmp'
contract f
sort f
gen fcode = _n
keep f fcode
save `tmp', replace
* return to marriage data for aggregation
restore
* aggregate by husband-wife pairs, by period
gen m = 1
collapse (sum) m, by(husband wife period)
* numbers for the text
* marriages between Contarini and Morosini
list wife husband m if period == 1 & ((wife == "Contarini" & husband == "Morosini") | (wife == "Morosini" & husband == "Contarini"))
* marriages between Michiel and Contarini and between Michiel and Morosini
list wife husband m if period == 1 & ((wife == "Contarini" & husband == "Michiel") | (wife == "Michiel" & husband == "Contarini"))
list wife husband m if period == 1 & ((wife == "Michiel" & husband == "Morosini") | (wife == "Morosini" & husband == "Michiel"))
* complete list of families for wifes
rename wife f
merge m:1 f using `tmp'
drop _merge fcode
* complete list of families for husbands
rename (f husband) (wife f)
merge m:1 f using `tmp'
drop _merge fcode
rename f husband
* assign period 1 to additions, fillin will add other cases
replace period = 1 if missing(period)
* rectangularise data
fillin husband wife period
drop _fillin
drop if missing(wife) | missing(husband)
mvencode m, mv(0)
* assign unique code to wife's family
rename wife f
merge m:1 f using `tmp'
drop _merge
rename (f fcode) (wife wcode)
* assign unique code to husband's family
rename husband f
merge m:1 f using `tmp'
rename (f fcode) (husband hcode)
drop _merge
sort period hcode wcode
* make data wide to prepare adjacency matrix
drop wife
reshape wide m, i(hcode period) j(wcode)
aorder m*
order husband hcode period
* create blank data file before start of period loop
preserve
clear
set obs 1
gen hcode = .
save `tmp', replace
restore
* loop through periods
forvalues i = 1/2 {
	preserve
	keep if period == `i'
	mkmat m*, matrix(B)
	drop m*
	* undirected network
	mat A = B + B' - diag(vecdiag(B))
	* compute eigenvalues (v) and eigenvectors (X)
	matrix symeigen X v = A
	* recover eigenvectors
	svmat X, names(col)
	rename e* e*vec
	* recover eigenvalues
	svmat v, names(col)
	* assign eigenvalues to all families
	local nf = _N
	forval j = 1/`nf' {
		egen e`j'val = min(e`j')
		drop e`j'
	}
	aorder e*
	order husband hcode period
	rename husband familyname_std
	append using `tmp'
	save `tmp', replace
	restore
}
use `tmp', clear
drop if missing(hcode)
* eigenvector centrality
sort period
by period: egen e1vec_max = max(e1vec)
gen centrality = (e1vec / e1vec_max)
* save centrality for gephi
gen Id = proper(familyname_std)
outsheet Id centrality if period == 1 using eg4gephi.csv, comma replace
drop Id
* keep centrality
keep familyname period centrality
reshape wide centrality, i(familyname_std) j(period)
* merge gc seats
merge m:1 familyname_std using `stdseats'
mvencode centrality* if _merge == 2, mv(0)
mvencode seats_family_peryear if _merge == 1, mv(0)
drop _merge
keep familyname_std centrality1 centrality2 seats_family_peryear
* calculate percentile in seat distribution
egen seats_family_rank = rank(-seats_family_peryear), track
gen seats_family_pctl = 100 * (1 - seats_family_rank / _N)
* generate labels for figure
gen familyname_lbl = ""
replace familyname_lbl = ""
replace familyname_lbl = proper(familyname_std) if (centrality1 > 0.3) 
replace familyname_lbl = proper(familyname_std) if /*
*/ (familyname_std == "Michiel" /*
*/ | familyname_std == "Pesaro" | familyname_std == "Priuli" /*
*/ | familyname_std == "Tron" | familyname_std == "Venier")
* centrality against gc seats
twoway (scatter centrality1 seats_family_pctl, mlabel(familyname_lbl) mlabposition(3)/*
*/ xaxis (1 2) /* 
*/ xtitle("Percentile in the Great Council seat distribution: 1261-1295" "(seats per session in parentheses)", axis(1)) /*
*/ xtitle("", axis(2))/*
*/ xlabel(24.04 "24%" 35.01 "36%" 39.17 "40%" 49.55 "50%" 60 "60%" 70 "70%" 80 "80%" 90 "90%" 100 "100%", axis(1) labsize(medsmall) angle(horizontal)) /*
*/ xlabel(24.04 "(0)" 35.01 "(.05)" 39.17 "(.10)" 49.55 "(.25)" 60 "(.50)" 70 "(.90)" 80 "(1.7)" 90 "(3.3)" 100 "(20)", axis(2) labsize(small) angle(horizontal)) /*
*/ ytitle("Centrality in the marriage network: 1400s") /*
*/ ylabel(0 .1(.1)1) /*
*/ msize(small) mlcolor(black) mlwidth(vthin) /*
*/ legend(off))
* save as eps
*graph export "venice_fsrc_ec_seats.eps", as(eps) preview(off) replace
* persistence in centrality
twoway (scatter centrality2 centrality1, mlabel(familyname_lbl) mlabposition(3)/*
*/ ytitle("Centrality in the marriage network: 1500s") /*
*/ xtitle("Centrality in the marriage network: 1400s") /*
*/ xlabel(0 .1(.1)1) /*
*/ ylabel(0 .1(.1)1) /*
*/ msize(small) mlcolor(black) mlwidth(vthin) /*
*/ legend(off))
* save as eps
*graph export "venice_fsrc_ec_persist.eps", as(eps) preview(off) replace

/* 
table: colleganza 
*/
use venice_colleganza, clear
* colleganza contracts for which we have the settlement or another document
count if contract_type == "repeat"
* keep only colleganza contracts
keep if contract_type == "colleganza" | contract_type == "colleganza settlement" | contract_type == "colleganza reference"
* total number of colleganza contracts
count
* identify commoners as those without family in great council 1261-1323
gen commoner_stans = 0
gen commoner_tractor = 0
replace commoner_stans = 1 if missing(stans_familyname_std_gc) | (!missing(stans_2_familyname_italian) & missing(stans_2_familyname_std_gc))
replace commoner_tractor = 1 if missing(tractor_familyname_std_gc) | (!missing(tractor_2_familyname_italian) & missing(tractor_2_familyname_std_gc))
* aggregate commoner info
gen commoner_involved = 0
replace commoner_involved = 1 if commoner_stans | commoner_tractor
* periods
sort year
gen period = ""
gen period_years = .
replace period = "1073--1200" if year >= 1073 & year <= 1200
replace period_years = 1200-1073+1 if period == "1073--1200"
replace period = "1201--1220" if year >= 1201 & year <= 1220
replace period_years = 1220-1201+1 if period == "1201--1220"
replace period = "1221--1240" if year >= 1221 & year <= 1240
replace period_years = 1240-1221+1 if period == "1221--1240"
replace period = "1241--1261" if year >= 1241 & year <= 1261
replace period_years = 1261-1241+1 if period == "1241--1261"
replace period = "1262--1309" if year >= 1262 & year <= 1309
replace period_years = 1309-1262+1 if period == "1262--1309"
replace period = "1310--1323" if year >= 1310 & year <= 1323
replace period_years = 1323-1310+1 if period == "1310--1323"
replace period = "1324"      if year == 1324
replace period_years = 1 if period == "1324"
replace period = "1325--1330" if year >= 1325 & year <= 1330
replace period_years = 1330-1325+1 if period == "1325--1330"
replace period = "1331--1338" if year >= 1331 & year <= 1338
replace period_years = 1338-1331+1 if period == "1331--1338"
replace period = "1339--1342" if year >= 1339 & year <= 1342
replace period_years = 1342-1339+1 if period == "1339--1342"
* match std family names and set shares with merchants
foreach p in "tractor" "tractor_2" "stans" "stans_2" {
  * std familyname
  gen familyname_std = `p'_familyname_std_gc
  * seat measures for merchant family
  merge m:1 familyname_std using `stdseats'
  drop if _merge == 2
  drop _merge
  drop familyname_std
  rename seats_family* `p'_seats_family*
}
* deal with families without seats
mvencode *seats_family_rank, mv(999)
mvencode *seats_family*, mv(0)
preserve
* look at seat shares of colleganza parties
gen firstname1 = proper(tractor_firstname_italian)
gen firstname2 = proper(stans_firstname_italian)
gen firstname3 = proper(tractor_2_firstname_italian)
gen firstname4 = proper(stans_2_firstname_italian)
gen familyname1 = proper(tractor_familyname_italian)
gen familyname2 = proper(stans_familyname_italian)
gen familyname3 = proper(tractor_2_familyname_italian)
gen familyname4 = proper(stans_2_familyname_italian)
gen familyname_std1 = proper(tractor_familyname_std_gc)
gen familyname_std2 = proper(stans_familyname_std_gc)
gen familyname_std3 = proper(tractor_2_familyname_std_gc)
gen familyname_std4 = proper(stans_2_familyname_std_gc)
replace familyname1 = familyname_std1 if !missing(familyname_std1)
replace familyname2 = familyname_std2 if !missing(familyname_std2)
replace familyname3 = familyname_std3 if !missing(familyname_std3)
replace familyname4 = familyname_std4 if !missing(familyname_std4)
drop familyname_std1 familyname_std2 familyname_std3 familyname_std4
rename tractor_seats_family_* seats*1
rename stans_seats_family_* seats*2
rename tractor_2_seats_family_* seats*3
rename stans_2_seats_family_* seats*4
keep firstname* familyname* seats* source docnumber year period
reshape long firstname familyname seatsperyear seatsrank seatspctl, i(source docnumber period year) j(party)
drop if party == 3 & missing(familyname)
drop if party == 4 & missing(familyname)
collapse (first) seatsperyear seatsrank seatspctl, by(period firstname familyname)
collapse (median) median_seatsperyear = seatsperyear, by(period)
save `tmp', replace
restore
gen contracts = 1
collapse (sum) contracts commoner_involved commoner_stans commoner_tractor, by(period period_years)
gen commoner_pct = 100*commoner_involved / contracts
gen commoner_stans_pct = 100*commoner_stans / contracts
gen commoner_tractor_pct = 100*commoner_tractor / contracts
drop period_years
merge 1:1 period using `tmp'
drop _merge
gen navigantium = ""
replace navigantium = "In force" if period == "1324" | period == "1331--1338"
gen str commoner_pct_txt = string(commoner_pct,"%9.0f") + "\%"
order period contracts commoner_involved commoner_pct_txt median_seatsperyear navigantium
format median_seatsperyear %9.1f
* output table
gen str1 ampersand = "&"
gen str4 slash = "\\"
outsheet period ampersand contracts ampersand commoner_involved ampersand commoner_pct_txt ampersand median_seatsperyear ampersand navigantium slash using venice_table.tex, nonames noquote replace

log close
